@@ -9,7 +9,7 @@ our @EXPORT_OK = qw($LVL_MAP);
 our $LVL_MAP = {
     FATAL  => -2,
     ERROR  => -1,
-    NOTICE => -1,
+    ALERT  => -1,
     WARN   =>  0,
     INFO   =>  1,
     DEBUG  =>  2,
